# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.4.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKStatisticsPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if getattr(globals().get("__spec__"), "parent", None) or __package__ or "." in __name__:
    from . import _itkScalarImageToRunLengthFeaturesFilterPython
else:
    import _itkScalarImageToRunLengthFeaturesFilterPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkImagePython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.itkMatrixPython
import itk.itkVectorPython
import itk.vnl_vector_refPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.itkCovariantVectorPython
import itk.itkPointPython
import itk.vnl_matrix_fixedPython
import itk.itkImageRegionPython
import itk.itkIndexPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.ITKCommonBasePython
import itk.itkRGBPixelPython
import itk.itkRGBAPixelPython
import itk.itkVectorContainerPython
import itk.itkArrayPython
import itk.itkContinuousIndexPython

def itkScalarImageToRunLengthFeaturesFilterIF2_New():
    return itkScalarImageToRunLengthFeaturesFilterIF2.New()

class itkScalarImageToRunLengthFeaturesFilterIF2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToRunLengthFeaturesFilterIF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToRunLengthFeaturesFilterIF2_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToRunLengthFeaturesFilterIF2_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageF2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageF2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: float
        max: float

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetPixelValueMinMax(self, min, max)

    def SetDistanceValueMinMax(self, min, max):
        r"""
        SetDistanceValueMinMax(self, min, max)

        Parameters
        ----------
        min: double
        max: double

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetDistanceValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageF2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageF2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: float

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToRunLengthFeaturesFilterPython.delete_itkScalarImageToRunLengthFeaturesFilterIF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToRunLengthFeaturesFilterIF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToRunLengthFeaturesFilterIF2

        Create a new object of the class itkScalarImageToRunLengthFeaturesFilterIF2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToRunLengthFeaturesFilterIF2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToRunLengthFeaturesFilterIF2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToRunLengthFeaturesFilterIF2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToRunLengthFeaturesFilterIF2 in _itkScalarImageToRunLengthFeaturesFilterPython:
_itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF2_swigregister(itkScalarImageToRunLengthFeaturesFilterIF2)

def itkScalarImageToRunLengthFeaturesFilterIF3_New():
    return itkScalarImageToRunLengthFeaturesFilterIF3.New()

class itkScalarImageToRunLengthFeaturesFilterIF3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToRunLengthFeaturesFilterIF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToRunLengthFeaturesFilterIF3_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToRunLengthFeaturesFilterIF3_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageF3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageF3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: float
        max: float

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetPixelValueMinMax(self, min, max)

    def SetDistanceValueMinMax(self, min, max):
        r"""
        SetDistanceValueMinMax(self, min, max)

        Parameters
        ----------
        min: double
        max: double

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetDistanceValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageF3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageF3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: float

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToRunLengthFeaturesFilterPython.delete_itkScalarImageToRunLengthFeaturesFilterIF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToRunLengthFeaturesFilterIF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToRunLengthFeaturesFilterIF3

        Create a new object of the class itkScalarImageToRunLengthFeaturesFilterIF3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToRunLengthFeaturesFilterIF3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToRunLengthFeaturesFilterIF3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToRunLengthFeaturesFilterIF3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToRunLengthFeaturesFilterIF3 in _itkScalarImageToRunLengthFeaturesFilterPython:
_itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIF3_swigregister(itkScalarImageToRunLengthFeaturesFilterIF3)

def itkScalarImageToRunLengthFeaturesFilterISS2_New():
    return itkScalarImageToRunLengthFeaturesFilterISS2.New()

class itkScalarImageToRunLengthFeaturesFilterISS2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToRunLengthFeaturesFilterISS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToRunLengthFeaturesFilterISS2_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToRunLengthFeaturesFilterISS2_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageSS2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: short
        max: short

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetPixelValueMinMax(self, min, max)

    def SetDistanceValueMinMax(self, min, max):
        r"""
        SetDistanceValueMinMax(self, min, max)

        Parameters
        ----------
        min: double
        max: double

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetDistanceValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: short

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToRunLengthFeaturesFilterPython.delete_itkScalarImageToRunLengthFeaturesFilterISS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToRunLengthFeaturesFilterISS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToRunLengthFeaturesFilterISS2

        Create a new object of the class itkScalarImageToRunLengthFeaturesFilterISS2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToRunLengthFeaturesFilterISS2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToRunLengthFeaturesFilterISS2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToRunLengthFeaturesFilterISS2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToRunLengthFeaturesFilterISS2 in _itkScalarImageToRunLengthFeaturesFilterPython:
_itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS2_swigregister(itkScalarImageToRunLengthFeaturesFilterISS2)

def itkScalarImageToRunLengthFeaturesFilterISS3_New():
    return itkScalarImageToRunLengthFeaturesFilterISS3.New()

class itkScalarImageToRunLengthFeaturesFilterISS3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToRunLengthFeaturesFilterISS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToRunLengthFeaturesFilterISS3_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToRunLengthFeaturesFilterISS3_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageSS3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: short
        max: short

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetPixelValueMinMax(self, min, max)

    def SetDistanceValueMinMax(self, min, max):
        r"""
        SetDistanceValueMinMax(self, min, max)

        Parameters
        ----------
        min: double
        max: double

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetDistanceValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageSS3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageSS3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: short

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToRunLengthFeaturesFilterPython.delete_itkScalarImageToRunLengthFeaturesFilterISS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToRunLengthFeaturesFilterISS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToRunLengthFeaturesFilterISS3

        Create a new object of the class itkScalarImageToRunLengthFeaturesFilterISS3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToRunLengthFeaturesFilterISS3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToRunLengthFeaturesFilterISS3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToRunLengthFeaturesFilterISS3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToRunLengthFeaturesFilterISS3 in _itkScalarImageToRunLengthFeaturesFilterPython:
_itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterISS3_swigregister(itkScalarImageToRunLengthFeaturesFilterISS3)

def itkScalarImageToRunLengthFeaturesFilterIUC2_New():
    return itkScalarImageToRunLengthFeaturesFilterIUC2.New()

class itkScalarImageToRunLengthFeaturesFilterIUC2(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToRunLengthFeaturesFilterIUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToRunLengthFeaturesFilterIUC2_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToRunLengthFeaturesFilterIUC2_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageUC2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: unsigned char
        max: unsigned char

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetPixelValueMinMax(self, min, max)

    def SetDistanceValueMinMax(self, min, max):
        r"""
        SetDistanceValueMinMax(self, min, max)

        Parameters
        ----------
        min: double
        max: double

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetDistanceValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC2 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC2"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: unsigned char

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToRunLengthFeaturesFilterPython.delete_itkScalarImageToRunLengthFeaturesFilterIUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToRunLengthFeaturesFilterIUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToRunLengthFeaturesFilterIUC2

        Create a new object of the class itkScalarImageToRunLengthFeaturesFilterIUC2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToRunLengthFeaturesFilterIUC2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToRunLengthFeaturesFilterIUC2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToRunLengthFeaturesFilterIUC2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToRunLengthFeaturesFilterIUC2 in _itkScalarImageToRunLengthFeaturesFilterPython:
_itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC2_swigregister(itkScalarImageToRunLengthFeaturesFilterIUC2)

def itkScalarImageToRunLengthFeaturesFilterIUC3_New():
    return itkScalarImageToRunLengthFeaturesFilterIUC3.New()

class itkScalarImageToRunLengthFeaturesFilterIUC3(itk.ITKCommonBasePython.itkProcessObject):
    r"""Proxy of C++ itkScalarImageToRunLengthFeaturesFilterIUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkScalarImageToRunLengthFeaturesFilterIUC3_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkScalarImageToRunLengthFeaturesFilterIUC3_Pointer"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_Clone(self)

    def GetFeatureMeansOutput(self):
        r"""GetFeatureMeansOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetFeatureMeansOutput(self)

    def GetFeatureStandardDeviationsOutput(self):
        r"""GetFeatureStandardDeviationsOutput(self) -> itkDataObjectDecoratorVCUCD"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetFeatureStandardDeviationsOutput(self)

    def SetInput(self, arg0):
        r"""
        SetInput(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetInput(self, arg0)

    def GetInput(self):
        r"""GetInput(self) -> itkImageUC3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetInput(self)

    def GetFeatureMeans(self):
        r"""GetFeatureMeans(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetFeatureMeans(self)

    def GetFeatureStandardDeviations(self):
        r"""GetFeatureStandardDeviations(self) -> itkVectorContainerUCD_Pointer const &"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetFeatureStandardDeviations(self)

    def SetRequestedFeatures(self, _arg):
        r"""
        SetRequestedFeatures(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCUC const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetRequestedFeatures(self, _arg)

    def GetRequestedFeatures(self):
        r"""GetRequestedFeatures(self) -> itkVectorContainerUCUC"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetRequestedFeatures(self)

    def SetOffsets(self, _arg):
        r"""
        SetOffsets(self, _arg)

        Parameters
        ----------
        _arg: itkVectorContainerUCO3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetOffsets(self, _arg)

    def GetOffsets(self):
        r"""GetOffsets(self) -> itkVectorContainerUCO3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetOffsets(self)

    def SetNumberOfBinsPerAxis(self, arg0):
        r"""
        SetNumberOfBinsPerAxis(self, arg0)

        Parameters
        ----------
        arg0: unsigned int

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetNumberOfBinsPerAxis(self, arg0)

    def SetPixelValueMinMax(self, min, max):
        r"""
        SetPixelValueMinMax(self, min, max)

        Parameters
        ----------
        min: unsigned char
        max: unsigned char

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetPixelValueMinMax(self, min, max)

    def SetDistanceValueMinMax(self, min, max):
        r"""
        SetDistanceValueMinMax(self, min, max)

        Parameters
        ----------
        min: double
        max: double

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetDistanceValueMinMax(self, min, max)

    def SetMaskImage(self, arg0):
        r"""
        SetMaskImage(self, arg0)

        Parameters
        ----------
        arg0: itkImageUC3 const *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetMaskImage(self, arg0)

    def GetMaskImage(self):
        r"""GetMaskImage(self) -> itkImageUC3"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetMaskImage(self)

    def SetInsidePixelValue(self, insidePixelValue):
        r"""
        SetInsidePixelValue(self, insidePixelValue)

        Parameters
        ----------
        insidePixelValue: unsigned char

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetInsidePixelValue(self, insidePixelValue)

    def GetFastCalculations(self):
        r"""GetFastCalculations(self) -> bool"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_GetFastCalculations(self)

    def SetFastCalculations(self, _arg):
        r"""
        SetFastCalculations(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_SetFastCalculations(self, _arg)

    def FastCalculationsOn(self):
        r"""FastCalculationsOn(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_FastCalculationsOn(self)

    def FastCalculationsOff(self):
        r"""FastCalculationsOff(self)"""
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_FastCalculationsOff(self)
    __swig_destroy__ = _itkScalarImageToRunLengthFeaturesFilterPython.delete_itkScalarImageToRunLengthFeaturesFilterIUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkScalarImageToRunLengthFeaturesFilterIUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkScalarImageToRunLengthFeaturesFilterIUC3

        Create a new object of the class itkScalarImageToRunLengthFeaturesFilterIUC3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkScalarImageToRunLengthFeaturesFilterIUC3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkScalarImageToRunLengthFeaturesFilterIUC3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkScalarImageToRunLengthFeaturesFilterIUC3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkScalarImageToRunLengthFeaturesFilterIUC3 in _itkScalarImageToRunLengthFeaturesFilterPython:
_itkScalarImageToRunLengthFeaturesFilterPython.itkScalarImageToRunLengthFeaturesFilterIUC3_swigregister(itkScalarImageToRunLengthFeaturesFilterIUC3)

from itk.support import helpers
import itk.support.types as itkt
from typing import Sequence, Tuple, Union

@helpers.accept_array_like_xarray_torch
def scalar_image_to_run_length_features_filter(*args,  requested_features: Sequence[int]=..., offsets: Sequence[Sequence[int]]=..., number_of_bins_per_axis: int=..., pixel_value_min_max: int=..., distance_value_min_max: float=..., mask_image: itkt.Image=..., inside_pixel_value: int=..., fast_calculations: bool=...,**kwargs):
    """Functional interface for ScalarImageToRunLengthFeaturesFilter"""
    import itk

    kwarg_typehints = { 'requested_features':requested_features,'offsets':offsets,'number_of_bins_per_axis':number_of_bins_per_axis,'pixel_value_min_max':pixel_value_min_max,'distance_value_min_max':distance_value_min_max,'mask_image':mask_image,'inside_pixel_value':inside_pixel_value,'fast_calculations':fast_calculations }
    specified_kwarg_typehints = { k:v for (k,v) in kwarg_typehints.items() if kwarg_typehints[k] is not ... }
    kwargs.update(specified_kwarg_typehints)


    instance = itk.ScalarImageToRunLengthFeaturesFilter.New(*args, **kwargs)

    return instance.__internal_call__()

def scalar_image_to_run_length_features_filter_init_docstring():
    import itk
    from itk.support import template_class

    filter_class = itk.ITKStatistics.ScalarImageToRunLengthFeaturesFilter
    scalar_image_to_run_length_features_filter.process_object = filter_class
    is_template = isinstance(filter_class, template_class.itkTemplate)
    if is_template:
        filter_object = filter_class.values()[0]
    else:
        filter_object = filter_class

    scalar_image_to_run_length_features_filter.__doc__ = filter_object.__doc__



